# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ydb._grpc.v3.protos import ydb_table_pb2 as protos_dot_ydb__table__pb2


class TableServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSession = channel.unary_unary(
                '/Ydb.Table.V1.TableService/CreateSession',
                request_serializer=protos_dot_ydb__table__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.CreateSessionResponse.FromString,
                )
        self.DeleteSession = channel.unary_unary(
                '/Ydb.Table.V1.TableService/DeleteSession',
                request_serializer=protos_dot_ydb__table__pb2.DeleteSessionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.DeleteSessionResponse.FromString,
                )
        self.KeepAlive = channel.unary_unary(
                '/Ydb.Table.V1.TableService/KeepAlive',
                request_serializer=protos_dot_ydb__table__pb2.KeepAliveRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.KeepAliveResponse.FromString,
                )
        self.CreateTable = channel.unary_unary(
                '/Ydb.Table.V1.TableService/CreateTable',
                request_serializer=protos_dot_ydb__table__pb2.CreateTableRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.CreateTableResponse.FromString,
                )
        self.DropTable = channel.unary_unary(
                '/Ydb.Table.V1.TableService/DropTable',
                request_serializer=protos_dot_ydb__table__pb2.DropTableRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.DropTableResponse.FromString,
                )
        self.AlterTable = channel.unary_unary(
                '/Ydb.Table.V1.TableService/AlterTable',
                request_serializer=protos_dot_ydb__table__pb2.AlterTableRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.AlterTableResponse.FromString,
                )
        self.CopyTable = channel.unary_unary(
                '/Ydb.Table.V1.TableService/CopyTable',
                request_serializer=protos_dot_ydb__table__pb2.CopyTableRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.CopyTableResponse.FromString,
                )
        self.CopyTables = channel.unary_unary(
                '/Ydb.Table.V1.TableService/CopyTables',
                request_serializer=protos_dot_ydb__table__pb2.CopyTablesRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.CopyTablesResponse.FromString,
                )
        self.RenameTables = channel.unary_unary(
                '/Ydb.Table.V1.TableService/RenameTables',
                request_serializer=protos_dot_ydb__table__pb2.RenameTablesRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.RenameTablesResponse.FromString,
                )
        self.DescribeTable = channel.unary_unary(
                '/Ydb.Table.V1.TableService/DescribeTable',
                request_serializer=protos_dot_ydb__table__pb2.DescribeTableRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.DescribeTableResponse.FromString,
                )
        self.ExplainDataQuery = channel.unary_unary(
                '/Ydb.Table.V1.TableService/ExplainDataQuery',
                request_serializer=protos_dot_ydb__table__pb2.ExplainDataQueryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.ExplainDataQueryResponse.FromString,
                )
        self.PrepareDataQuery = channel.unary_unary(
                '/Ydb.Table.V1.TableService/PrepareDataQuery',
                request_serializer=protos_dot_ydb__table__pb2.PrepareDataQueryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.PrepareDataQueryResponse.FromString,
                )
        self.ExecuteDataQuery = channel.unary_unary(
                '/Ydb.Table.V1.TableService/ExecuteDataQuery',
                request_serializer=protos_dot_ydb__table__pb2.ExecuteDataQueryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.ExecuteDataQueryResponse.FromString,
                )
        self.ExecuteSchemeQuery = channel.unary_unary(
                '/Ydb.Table.V1.TableService/ExecuteSchemeQuery',
                request_serializer=protos_dot_ydb__table__pb2.ExecuteSchemeQueryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.ExecuteSchemeQueryResponse.FromString,
                )
        self.BeginTransaction = channel.unary_unary(
                '/Ydb.Table.V1.TableService/BeginTransaction',
                request_serializer=protos_dot_ydb__table__pb2.BeginTransactionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.BeginTransactionResponse.FromString,
                )
        self.CommitTransaction = channel.unary_unary(
                '/Ydb.Table.V1.TableService/CommitTransaction',
                request_serializer=protos_dot_ydb__table__pb2.CommitTransactionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.CommitTransactionResponse.FromString,
                )
        self.RollbackTransaction = channel.unary_unary(
                '/Ydb.Table.V1.TableService/RollbackTransaction',
                request_serializer=protos_dot_ydb__table__pb2.RollbackTransactionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.RollbackTransactionResponse.FromString,
                )
        self.DescribeTableOptions = channel.unary_unary(
                '/Ydb.Table.V1.TableService/DescribeTableOptions',
                request_serializer=protos_dot_ydb__table__pb2.DescribeTableOptionsRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.DescribeTableOptionsResponse.FromString,
                )
        self.StreamReadTable = channel.unary_stream(
                '/Ydb.Table.V1.TableService/StreamReadTable',
                request_serializer=protos_dot_ydb__table__pb2.ReadTableRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.ReadTableResponse.FromString,
                )
        self.BulkUpsert = channel.unary_unary(
                '/Ydb.Table.V1.TableService/BulkUpsert',
                request_serializer=protos_dot_ydb__table__pb2.BulkUpsertRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.BulkUpsertResponse.FromString,
                )
        self.StreamExecuteScanQuery = channel.unary_stream(
                '/Ydb.Table.V1.TableService/StreamExecuteScanQuery',
                request_serializer=protos_dot_ydb__table__pb2.ExecuteScanQueryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__table__pb2.ExecuteScanQueryPartialResponse.FromString,
                )


class TableServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateSession(self, request, context):
        """Create new session. Implicit session creation is forbidden,
        so user must create new session before execute any query,
        otherwise BAD_SESSION status will be returned.
        Simultaneous execution of requests are forbiden.
        Sessions are volatile, can be invalidated by server, for example in case
        of fatal errors. All requests with this session will fail with BAD_SESSION status.
        So, client must be able to handle BAD_SESSION status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSession(self, request, context):
        """Ends a session, releasing server resources associated with it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KeepAlive(self, request, context):
        """Idle sessions can be kept alive by calling KeepAlive periodically.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTable(self, request, context):
        """Creates new table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DropTable(self, request, context):
        """Drop table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AlterTable(self, request, context):
        """Modifies schema of given table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CopyTable(self, request, context):
        """Creates copy of given table.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CopyTables(self, request, context):
        """Creates consistent copy of given tables.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameTables(self, request, context):
        """Creates consistent move of given tables.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeTable(self, request, context):
        """Returns information about given table (metadata).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExplainDataQuery(self, request, context):
        """Explains data query.
        SessionId of previously created session must be provided.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrepareDataQuery(self, request, context):
        """Prepares data query, returns query id.
        SessionId of previously created session must be provided.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteDataQuery(self, request, context):
        """Executes data query.
        SessionId of previously created session must be provided.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteSchemeQuery(self, request, context):
        """Executes scheme query.
        SessionId of previously created session must be provided.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BeginTransaction(self, request, context):
        """Begins new transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommitTransaction(self, request, context):
        """Commits specified active transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RollbackTransaction(self, request, context):
        """Performs a rollback of the specified active transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeTableOptions(self, request, context):
        """Describe supported table options.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamReadTable(self, request, context):
        """Streaming read table
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BulkUpsert(self, request, context):
        """Upserts a batch of rows non-transactionally.
        Returns success only when all rows were successfully upserted. In case of an error some rows might
        be upserted and some might not.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamExecuteScanQuery(self, request, context):
        """Executes scan query with streaming result.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TableServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSession,
                    request_deserializer=protos_dot_ydb__table__pb2.CreateSessionRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.CreateSessionResponse.SerializeToString,
            ),
            'DeleteSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSession,
                    request_deserializer=protos_dot_ydb__table__pb2.DeleteSessionRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.DeleteSessionResponse.SerializeToString,
            ),
            'KeepAlive': grpc.unary_unary_rpc_method_handler(
                    servicer.KeepAlive,
                    request_deserializer=protos_dot_ydb__table__pb2.KeepAliveRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.KeepAliveResponse.SerializeToString,
            ),
            'CreateTable': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTable,
                    request_deserializer=protos_dot_ydb__table__pb2.CreateTableRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.CreateTableResponse.SerializeToString,
            ),
            'DropTable': grpc.unary_unary_rpc_method_handler(
                    servicer.DropTable,
                    request_deserializer=protos_dot_ydb__table__pb2.DropTableRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.DropTableResponse.SerializeToString,
            ),
            'AlterTable': grpc.unary_unary_rpc_method_handler(
                    servicer.AlterTable,
                    request_deserializer=protos_dot_ydb__table__pb2.AlterTableRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.AlterTableResponse.SerializeToString,
            ),
            'CopyTable': grpc.unary_unary_rpc_method_handler(
                    servicer.CopyTable,
                    request_deserializer=protos_dot_ydb__table__pb2.CopyTableRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.CopyTableResponse.SerializeToString,
            ),
            'CopyTables': grpc.unary_unary_rpc_method_handler(
                    servicer.CopyTables,
                    request_deserializer=protos_dot_ydb__table__pb2.CopyTablesRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.CopyTablesResponse.SerializeToString,
            ),
            'RenameTables': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameTables,
                    request_deserializer=protos_dot_ydb__table__pb2.RenameTablesRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.RenameTablesResponse.SerializeToString,
            ),
            'DescribeTable': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeTable,
                    request_deserializer=protos_dot_ydb__table__pb2.DescribeTableRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.DescribeTableResponse.SerializeToString,
            ),
            'ExplainDataQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.ExplainDataQuery,
                    request_deserializer=protos_dot_ydb__table__pb2.ExplainDataQueryRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.ExplainDataQueryResponse.SerializeToString,
            ),
            'PrepareDataQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.PrepareDataQuery,
                    request_deserializer=protos_dot_ydb__table__pb2.PrepareDataQueryRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.PrepareDataQueryResponse.SerializeToString,
            ),
            'ExecuteDataQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteDataQuery,
                    request_deserializer=protos_dot_ydb__table__pb2.ExecuteDataQueryRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.ExecuteDataQueryResponse.SerializeToString,
            ),
            'ExecuteSchemeQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteSchemeQuery,
                    request_deserializer=protos_dot_ydb__table__pb2.ExecuteSchemeQueryRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.ExecuteSchemeQueryResponse.SerializeToString,
            ),
            'BeginTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.BeginTransaction,
                    request_deserializer=protos_dot_ydb__table__pb2.BeginTransactionRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.BeginTransactionResponse.SerializeToString,
            ),
            'CommitTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.CommitTransaction,
                    request_deserializer=protos_dot_ydb__table__pb2.CommitTransactionRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.CommitTransactionResponse.SerializeToString,
            ),
            'RollbackTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.RollbackTransaction,
                    request_deserializer=protos_dot_ydb__table__pb2.RollbackTransactionRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.RollbackTransactionResponse.SerializeToString,
            ),
            'DescribeTableOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeTableOptions,
                    request_deserializer=protos_dot_ydb__table__pb2.DescribeTableOptionsRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.DescribeTableOptionsResponse.SerializeToString,
            ),
            'StreamReadTable': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamReadTable,
                    request_deserializer=protos_dot_ydb__table__pb2.ReadTableRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.ReadTableResponse.SerializeToString,
            ),
            'BulkUpsert': grpc.unary_unary_rpc_method_handler(
                    servicer.BulkUpsert,
                    request_deserializer=protos_dot_ydb__table__pb2.BulkUpsertRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.BulkUpsertResponse.SerializeToString,
            ),
            'StreamExecuteScanQuery': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamExecuteScanQuery,
                    request_deserializer=protos_dot_ydb__table__pb2.ExecuteScanQueryRequest.FromString,
                    response_serializer=protos_dot_ydb__table__pb2.ExecuteScanQueryPartialResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Ydb.Table.V1.TableService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TableService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/CreateSession',
            protos_dot_ydb__table__pb2.CreateSessionRequest.SerializeToString,
            protos_dot_ydb__table__pb2.CreateSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/DeleteSession',
            protos_dot_ydb__table__pb2.DeleteSessionRequest.SerializeToString,
            protos_dot_ydb__table__pb2.DeleteSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KeepAlive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/KeepAlive',
            protos_dot_ydb__table__pb2.KeepAliveRequest.SerializeToString,
            protos_dot_ydb__table__pb2.KeepAliveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/CreateTable',
            protos_dot_ydb__table__pb2.CreateTableRequest.SerializeToString,
            protos_dot_ydb__table__pb2.CreateTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DropTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/DropTable',
            protos_dot_ydb__table__pb2.DropTableRequest.SerializeToString,
            protos_dot_ydb__table__pb2.DropTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AlterTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/AlterTable',
            protos_dot_ydb__table__pb2.AlterTableRequest.SerializeToString,
            protos_dot_ydb__table__pb2.AlterTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CopyTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/CopyTable',
            protos_dot_ydb__table__pb2.CopyTableRequest.SerializeToString,
            protos_dot_ydb__table__pb2.CopyTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CopyTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/CopyTables',
            protos_dot_ydb__table__pb2.CopyTablesRequest.SerializeToString,
            protos_dot_ydb__table__pb2.CopyTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/RenameTables',
            protos_dot_ydb__table__pb2.RenameTablesRequest.SerializeToString,
            protos_dot_ydb__table__pb2.RenameTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DescribeTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/DescribeTable',
            protos_dot_ydb__table__pb2.DescribeTableRequest.SerializeToString,
            protos_dot_ydb__table__pb2.DescribeTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExplainDataQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/ExplainDataQuery',
            protos_dot_ydb__table__pb2.ExplainDataQueryRequest.SerializeToString,
            protos_dot_ydb__table__pb2.ExplainDataQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PrepareDataQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/PrepareDataQuery',
            protos_dot_ydb__table__pb2.PrepareDataQueryRequest.SerializeToString,
            protos_dot_ydb__table__pb2.PrepareDataQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteDataQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/ExecuteDataQuery',
            protos_dot_ydb__table__pb2.ExecuteDataQueryRequest.SerializeToString,
            protos_dot_ydb__table__pb2.ExecuteDataQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteSchemeQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/ExecuteSchemeQuery',
            protos_dot_ydb__table__pb2.ExecuteSchemeQueryRequest.SerializeToString,
            protos_dot_ydb__table__pb2.ExecuteSchemeQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BeginTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/BeginTransaction',
            protos_dot_ydb__table__pb2.BeginTransactionRequest.SerializeToString,
            protos_dot_ydb__table__pb2.BeginTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommitTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/CommitTransaction',
            protos_dot_ydb__table__pb2.CommitTransactionRequest.SerializeToString,
            protos_dot_ydb__table__pb2.CommitTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RollbackTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/RollbackTransaction',
            protos_dot_ydb__table__pb2.RollbackTransactionRequest.SerializeToString,
            protos_dot_ydb__table__pb2.RollbackTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DescribeTableOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/DescribeTableOptions',
            protos_dot_ydb__table__pb2.DescribeTableOptionsRequest.SerializeToString,
            protos_dot_ydb__table__pb2.DescribeTableOptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamReadTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Ydb.Table.V1.TableService/StreamReadTable',
            protos_dot_ydb__table__pb2.ReadTableRequest.SerializeToString,
            protos_dot_ydb__table__pb2.ReadTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BulkUpsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Table.V1.TableService/BulkUpsert',
            protos_dot_ydb__table__pb2.BulkUpsertRequest.SerializeToString,
            protos_dot_ydb__table__pb2.BulkUpsertResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamExecuteScanQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Ydb.Table.V1.TableService/StreamExecuteScanQuery',
            protos_dot_ydb__table__pb2.ExecuteScanQueryRequest.SerializeToString,
            protos_dot_ydb__table__pb2.ExecuteScanQueryPartialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_coordination_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_coordination_pb2 as protos_dot_ydb__coordination__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_coordination_v1.proto',
  package='Ydb.Coordination.V1',
  syntax='proto3',
  serialized_options=b'\n\030tech.ydb.coordination.v1B\020CoordinationGrpcP\001Z;github.com/ydb-platform/ydb-go-genproto/Ydb_Coordination_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19ydb_coordination_v1.proto\x12\x13Ydb.Coordination.V1\x1a\x1dprotos/ydb_coordination.proto2\xca\x03\n\x13\x43oordinationService\x12R\n\x07Session\x12 .Ydb.Coordination.SessionRequest\x1a!.Ydb.Coordination.SessionResponse(\x01\x30\x01\x12W\n\nCreateNode\x12#.Ydb.Coordination.CreateNodeRequest\x1a$.Ydb.Coordination.CreateNodeResponse\x12T\n\tAlterNode\x12\".Ydb.Coordination.AlterNodeRequest\x1a#.Ydb.Coordination.AlterNodeResponse\x12Q\n\x08\x44ropNode\x12!.Ydb.Coordination.DropNodeRequest\x1a\".Ydb.Coordination.DropNodeResponse\x12]\n\x0c\x44\x65scribeNode\x12%.Ydb.Coordination.DescribeNodeRequest\x1a&.Ydb.Coordination.DescribeNodeResponseBk\n\x18tech.ydb.coordination.v1B\x10\x43oordinationGrpcP\x01Z;github.com/ydb-platform/ydb-go-genproto/Ydb_Coordination_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__coordination__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_COORDINATIONSERVICE = _descriptor.ServiceDescriptor(
  name='CoordinationService',
  full_name='Ydb.Coordination.V1.CoordinationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=82,
  serialized_end=540,
  methods=[
  _descriptor.MethodDescriptor(
    name='Session',
    full_name='Ydb.Coordination.V1.CoordinationService.Session',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__coordination__pb2._SESSIONREQUEST,
    output_type=protos_dot_ydb__coordination__pb2._SESSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNode',
    full_name='Ydb.Coordination.V1.CoordinationService.CreateNode',
    index=1,
    containing_service=None,
    input_type=protos_dot_ydb__coordination__pb2._CREATENODEREQUEST,
    output_type=protos_dot_ydb__coordination__pb2._CREATENODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AlterNode',
    full_name='Ydb.Coordination.V1.CoordinationService.AlterNode',
    index=2,
    containing_service=None,
    input_type=protos_dot_ydb__coordination__pb2._ALTERNODEREQUEST,
    output_type=protos_dot_ydb__coordination__pb2._ALTERNODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DropNode',
    full_name='Ydb.Coordination.V1.CoordinationService.DropNode',
    index=3,
    containing_service=None,
    input_type=protos_dot_ydb__coordination__pb2._DROPNODEREQUEST,
    output_type=protos_dot_ydb__coordination__pb2._DROPNODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeNode',
    full_name='Ydb.Coordination.V1.CoordinationService.DescribeNode',
    index=4,
    containing_service=None,
    input_type=protos_dot_ydb__coordination__pb2._DESCRIBENODEREQUEST,
    output_type=protos_dot_ydb__coordination__pb2._DESCRIBENODERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COORDINATIONSERVICE)

DESCRIPTOR.services_by_name['CoordinationService'] = _COORDINATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_scripting_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos import ydb_scripting_pb2 as protos_dot_ydb__scripting__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ydb_scripting_v1.proto\x12\x10Ydb.Scripting.V1\x1a\x1aprotos/ydb_scripting.proto2\x9a\x02\n\x10ScriptingService\x12Q\n\nExecuteYql\x12 .Ydb.Scripting.ExecuteYqlRequest\x1a!.Ydb.Scripting.ExecuteYqlResponse\x12`\n\x10StreamExecuteYql\x12 .Ydb.Scripting.ExecuteYqlRequest\x1a(.Ydb.Scripting.ExecuteYqlPartialResponse0\x01\x12Q\n\nExplainYql\x12 .Ydb.Scripting.ExplainYqlRequest\x1a!.Ydb.Scripting.ExplainYqlResponseBQ\n\x15tech.ydb.scripting.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Scripting_V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb_scripting_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025tech.ydb.scripting.v1Z8github.com/ydb-platform/ydb-go-genproto/Ydb_Scripting_V1'
  _SCRIPTINGSERVICE._serialized_start=73
  _SCRIPTINGSERVICE._serialized_end=355
# @@protoc_insertion_point(module_scope)



from __future__ import absolute_import, unicode_literals

import posixpath

import ydb
from .cursor import Cursor
from .errors import DatabaseError


class Connection(object):

    deiver = None
    pool = None

    def __init__(self, endpoint, database=None, **conn_kwargs):
        self.endpoint = endpoint
        self.database = database
        self._conn_kwargs = conn_kwargs
        driver, pool = self._create_driver(self.endpoint, self.database, **conn_kwargs)
        self.driver = driver
        self.pool = pool

    def cursor(self):
        return Cursor(self)

    def execute(self, sql, parameters=None):
        return self.cursor().execute(sql, parameters)

    def executemany(self, sql, parameters):
        return self.cursor().executemany(sql, parameters)

    def describe(self, table_path):
        full_path = posixpath.join(self.database, table_path)
        try:
            res = self.pool.retry_operation_sync(
                lambda cli: cli.describe_table(full_path)
            )
            return res.columns
        except ydb.Error as e:
            raise DatabaseError(e.message, e.issues, e.status)

        except Exception:
            raise DatabaseError("Failed to describe table %r" % (table_path,))

    def check_exists(self, table_path):
        try:
            self.driver.scheme_client.describe_path(table_path)
            return True
        except ydb.SchemeError:
            return False

    def commit(self):
        pass

    def rollback(self):
        pass

    def close(self):
        if self.pool is not None:
            self.pool.stop()
        if self.driver is not None:
            self.driver.stop()

    @staticmethod
    def _create_endpoint(host, port):
        return "%s:%d" % (host, port)

    @staticmethod
    def _create_driver(endpoint, database, **conn_kwargs):
        driver_config = ydb.DriverConfig(
            endpoint,
            database=database,
            table_client_settings=ydb.TableClientSettings()
            .with_native_date_in_result_sets(True)
            .with_native_datetime_in_result_sets(True)
            .with_native_json_in_result_sets(True),
            **conn_kwargs
        )
        driver = ydb.Driver(driver_config)
        try:
            driver.wait(timeout=5, fail_fast=True)
        except ydb.Error as e:
            raise DatabaseError(e.message, e.issues, e.status)

        except Exception:
            driver.stop()
            raise DatabaseError(
                "Failed to connect to YDB, details %s"
                % driver.discovery_debug_details()
            )

        return driver, ydb.SessionPool(driver)



import functools
from google.protobuf.empty_pb2 import Empty
from . import issues, types, _apis, convert, scheme, operation, _utilities

X_YDB_SERVER_HINTS = "x-ydb-server-hints"
X_YDB_SESSION_CLOSE = "session-close"


def _check_session_is_closing(rpc_state, session_state):
    metadata = rpc_state.trailing_metadata()
    if X_YDB_SESSION_CLOSE in metadata.get(X_YDB_SERVER_HINTS, []):
        session_state.set_closing()


def bad_session_handler(func):
    @functools.wraps(func)
    def decorator(rpc_state, response_pb, session_state, *args, **kwargs):
        try:
            _check_session_is_closing(rpc_state, session_state)
            return func(rpc_state, response_pb, session_state, *args, **kwargs)
        except issues.BadSession:
            session_state.reset()
            raise

    return decorator


@bad_session_handler
def wrap_prepare_query_response(rpc_state, response_pb, session_state, yql_text):
    session_state.complete_query()
    issues._process_response(response_pb.operation)
    message = _apis.ydb_table.PrepareQueryResult()
    response_pb.operation.result.Unpack(message)
    data_query = types.DataQuery(yql_text, message.parameters_types)
    session_state.keep(data_query, message.query_id)
    return data_query


def prepare_request_factory(session_state, yql_text):
    request = session_state.start_query().attach_request(
        _apis.ydb_table.PrepareDataQueryRequest()
    )
    request.yql_text = yql_text
    return request


class AlterTableOperation(operation.Operation):
    def __init__(self, rpc_state, response_pb, driver):
        super(AlterTableOperation, self).__init__(rpc_state, response_pb, driver)
        self.ready = response_pb.operation.ready


def copy_tables_request_factory(session_state, source_destination_pairs):
    request = session_state.attach_request(_apis.ydb_table.CopyTablesRequest())
    for source_path, destination_path in source_destination_pairs:
        table_item = request.tables.add()
        table_item.source_path = source_path
        table_item.destination_path = destination_path
    return request


def rename_tables_request_factory(session_state, rename_items):
    request = session_state.attach_request(_apis.ydb_table.RenameTablesRequest())
    for item in rename_items:
        table_item = request.tables.add()
        table_item.source_path = item.source_path
        table_item.destination_path = item.destination_path
        table_item.replace_destination = item.replace_destination
    return request


def explain_data_query_request_factory(session_state, yql_text):
    request = session_state.start_query().attach_request(
        _apis.ydb_table.ExplainDataQueryRequest()
    )
    request.yql_text = yql_text
    return request


class _ExplainResponse(object):
    def __init__(self, ast, plan):
        self.query_ast = ast
        self.query_plan = plan


def wrap_explain_response(rpc_state, response_pb, session_state):
    session_state.complete_query()
    issues._process_response(response_pb.operation)
    message = _apis.ydb_table.ExplainQueryResult()
    response_pb.operation.result.Unpack(message)
    return _ExplainResponse(message.query_ast, message.query_plan)


@bad_session_handler
def wrap_execute_scheme_result(rpc_state, response_pb, session_state):
    session_state.complete_query()
    issues._process_response(response_pb.operation)
    message = _apis.ydb_table.ExecuteQueryResult()
    response_pb.operation.result.Unpack(message)
    return convert.ResultSets(message.result_sets)


def execute_scheme_request_factory(session_state, yql_text):
    request = session_state.start_query().attach_request(
        _apis.ydb_table.ExecuteSchemeQueryRequest()
    )
    request.yql_text = yql_text
    return request


@bad_session_handler
def wrap_describe_table_response(
    rpc_state, response_pb, sesssion_state, scheme_entry_cls
):
    issues._process_response(response_pb.operation)
    message = _apis.ydb_table.DescribeTableResult()
    response_pb.operation.result.Unpack(message)
    return scheme._wrap_scheme_entry(
        message.self,
        scheme_entry_cls,
        message.columns,
        message.primary_key,
        message.shard_key_bounds,
        message.indexes,
        message.table_stats if message.HasField("table_stats") else None,
        message.ttl_settings if message.HasField("ttl_settings") else None,
        message.attributes,
        message.partitioning_settings
        if message.HasField("partitioning_settings")
        else None,
        message.column_families,
        message.key_bloom_filter,
        message.read_replicas_settings
        if message.HasField("read_replicas_settings")
        else None,
        message.storage_settings if message.HasField("storage_settings") else None,
    )


def explicit_partitions_factory(primary_key, columns, split_points):
    column_types = {}
    pk = set(primary_key)
    for column in columns:
        if column.name in pk:
            column_types[column.name] = column.type

    explicit_partitions = _apis.ydb_table.ExplicitPartitions()
    for split_point in split_points:
        typed_value = explicit_partitions.split_points.add()
        split_point_type = types.TupleType()
        prefix_size = len(split_point.value)
        for pl_el_id, pk_name in enumerate(primary_key):
            if pl_el_id >= prefix_size:
                break

            split_point_type.add_element(column_types[pk_name])

        typed_value.type.MergeFrom(split_point_type.proto)
        typed_value.value.MergeFrom(
            convert.from_native_value(split_point_type.proto, split_point.value)
        )

    return explicit_partitions


def create_table_request_factory(session_state, path, table_description):
    if isinstance(table_description, _apis.ydb_table.CreateTableRequest):
        request = session_state.attach_request(table_description)
        return request

    request = _apis.ydb_table.CreateTableRequest()
    request.path = path
    request.primary_key.extend(list(table_description.primary_key))
    for column in table_description.columns:
        request.columns.add(name=column.name, type=column.type_pb, family=column.family)

    if table_description.profile is not None:
        request.profile.MergeFrom(table_description.profile.to_pb(table_description))

    for index in table_description.indexes:
        request.indexes.add().MergeFrom(index.to_pb())

    if table_description.ttl_settings is not None:
        request.ttl_settings.MergeFrom(table_description.ttl_settings.to_pb())

    request.attributes.update(table_description.attributes)

    if table_description.column_families:
        for column_family in table_description.column_families:
            request.column_families.add().MergeFrom(column_family.to_pb())

    if table_description.storage_settings is not None:
        request.storage_settings.MergeFrom(table_description.storage_settings.to_pb())

    if table_description.read_replicas_settings is not None:
        request.read_replicas_settings.MergeFrom(
            table_description.read_replicas_settings.to_pb()
        )

    if table_description.partitioning_settings is not None:
        request.partitioning_settings.MergeFrom(
            table_description.partitioning_settings.to_pb()
        )

    request.key_bloom_filter = table_description.key_bloom_filter
    if table_description.compaction_policy is not None:
        request.compaction_policy = table_description.compaction_policy
    if table_description.partition_at_keys is not None:
        request.partition_at_keys.MergeFrom(
            explicit_partitions_factory(
                list(table_description.primary_key),
                table_description.columns,
                table_description.partition_at_keys.split_points,
            )
        )

    elif table_description.uniform_partitions > 0:
        request.uniform_partitions = table_description.uniform_partitions

    return session_state.attach_request(request)


def keep_alive_request_factory(session_state):
    request = _apis.ydb_table.KeepAliveRequest()
    return session_state.attach_request(request)


@bad_session_handler
def cleanup_session(rpc_state, response_pb, session_state, session):
    issues._process_response(response_pb.operation)
    session_state.reset()
    return session


@bad_session_handler
def initialize_session(rpc_state, response_pb, session_state, session):
    issues._process_response(response_pb.operation)
    message = _apis.ydb_table.CreateSessionResult()
    response_pb.operation.result.Unpack(message)
    session_state.set_id(message.session_id).attach_endpoint(rpc_state.endpoint_key)
    return session


@bad_session_handler
def wrap_operation(rpc_state, response_pb, session_state, driver=None):
    return operation.Operation(rpc_state, response_pb, driver)


def wrap_operation_bulk_upsert(rpc_state, response_pb, driver=None):
    return operation.Operation(rpc_state, response_pb, driver)


@bad_session_handler
def wrap_keep_alive_response(rpc_state, response_pb, session_state, session):
    issues._process_response(response_pb.operation)
    return session


def describe_table_request_factory(session_state, path, settings=None):
    request = session_state.attach_request(_apis.ydb_table.DescribeTableRequest())
    request.path = path

    if (
        settings is not None
        and hasattr(settings, "include_shard_key_bounds")
        and settings.include_shard_key_bounds
    ):
        request.include_shard_key_bounds = settings.include_shard_key_bounds

    if (
        settings is not None
        and hasattr(settings, "include_table_stats")
        and settings.include_table_stats
    ):
        request.include_table_stats = settings.include_table_stats

    return request


def alter_table_request_factory(
    session_state,
    path,
    add_columns,
    drop_columns,
    alter_attributes,
    add_indexes,
    drop_indexes,
    set_ttl_settings,
    drop_ttl_settings,
    add_column_families,
    alter_column_families,
    alter_storage_settings,
    set_compaction_policy,
    alter_partitioning_settings,
    set_key_bloom_filter,
    set_read_replicas_settings,
):
    request = session_state.attach_request(_apis.ydb_table.AlterTableRequest(path=path))
    if add_columns is not None:
        for column in add_columns:
            request.add_columns.add(name=column.name, type=column.type_pb)

    if drop_columns is not None:
        request.drop_columns.extend(list(drop_columns))

    if drop_indexes is not None:
        request.drop_indexes.extend(list(drop_indexes))

    if add_indexes is not None:
        for index in add_indexes:
            request.add_indexes.add().MergeFrom(index.to_pb())

    if alter_attributes is not None:
        request.alter_attributes.update(alter_attributes)

    if set_ttl_settings is not None:
        request.set_ttl_settings.MergeFrom(set_ttl_settings.to_pb())

    if drop_ttl_settings is not None and drop_ttl_settings:
        request.drop_ttl_settings.MergeFrom(Empty())

    if add_column_families is not None:
        for column_family in add_column_families:
            request.add_column_families.add().MergeFrom(column_family.to_pb())

    if alter_column_families is not None:
        for column_family in alter_column_families:
            request.alter_column_families.add().MergeFrom(column_family.to_pb())

    if alter_storage_settings is not None:
        request.alter_storage_settings.MergeFrom(alter_storage_settings.to_pb())

    if set_compaction_policy is not None:
        request.set_compaction_policy = set_compaction_policy

    if alter_partitioning_settings is not None:
        request.alter_partitioning_settings.MergeFrom(
            alter_partitioning_settings.to_pb()
        )

    if set_key_bloom_filter is not None:
        request.set_key_bloom_filter = set_key_bloom_filter

    if set_read_replicas_settings is not None:
        request.set_read_replicas_settings.MergeFrom(set_read_replicas_settings.to_pb())

    return request


def read_table_request_factory(
    session_state,
    path,
    key_range=None,
    columns=None,
    ordered=False,
    row_limit=None,
    use_snapshot=None,
):
    request = _apis.ydb_table.ReadTableRequest()
    request.path = path
    request.ordered = ordered
    if key_range is not None and key_range.from_bound is not None:
        target_attribute = (
            "greater_or_equal" if key_range.from_bound.is_inclusive() else "greater"
        )
        getattr(request.key_range, target_attribute).MergeFrom(
            convert.to_typed_value_from_native(
                key_range.from_bound.type, key_range.from_bound.value
            )
        )

    if key_range is not None and key_range.to_bound is not None:
        target_attribute = (
            "less_or_equal" if key_range.to_bound.is_inclusive() else "less"
        )
        getattr(request.key_range, target_attribute).MergeFrom(
            convert.to_typed_value_from_native(
                key_range.to_bound.type, key_range.to_bound.value
            )
        )

    if columns is not None:
        for column in columns:
            request.columns.append(column)
    if row_limit:
        # NOTE(gvit): pylint cannot understand that row_limit is not None
        request.row_limit = row_limit  # pylint: disable=E5903
    if use_snapshot is not None:
        if isinstance(use_snapshot, bool):
            if use_snapshot:
                request.use_snapshot = _apis.FeatureFlag.ENABLED
            else:
                request.use_snapshot = _apis.FeatureFlag.DISABLED
        else:
            request.use_snapshot = use_snapshot
    return session_state.attach_request(request)


def bulk_upsert_request_factory(table, rows, column_types):
    request = _apis.ydb_table.BulkUpsertRequest()
    request.table = table
    request.rows.MergeFrom(
        convert.to_typed_value_from_native(types.ListType(column_types).proto, rows)
    )
    return request


def wrap_read_table_response(response):
    issues._process_response(response)
    return convert.ResultSet.from_message(response.result.result_set)


class SessionState(object):
    def __init__(self, table_client_settings):
        self._session_id = None
        self._query_cache = _utilities.LRUCache(1000)
        self._default = (None, None)
        self._pending_query = False
        self._endpoint = None
        self._closing = False
        self._client_cache_enabled = table_client_settings._client_query_cache_enabled
        self.table_client_settings = table_client_settings

    def __contains__(self, query):
        return self.lookup(query) != self._default

    def reset(self):
        self._query_cache = _utilities.LRUCache(1000)
        self._session_id = None
        self._pending_query = False
        self._endpoint = None

    def attach_endpoint(self, endpoint):
        self._endpoint = endpoint
        return self

    def set_closing(self):
        self._closing = True
        return self

    def closing(self):
        return self._closing

    @property
    def endpoint(self):
        return self._endpoint

    @property
    def session_id(self):
        return self._session_id

    def pending_query(self):
        return self._pending_query

    def set_id(self, session_id):
        self._session_id = session_id
        return self

    def keep(self, query, query_id):
        if self._client_cache_enabled:
            self._query_cache.put(query.name, (query, query_id))
        else:
            self._query_cache.put(query.name, (query, None))
        return self

    @staticmethod
    def _query_key(query):
        return (
            query.name
            if isinstance(query, types.DataQuery)
            else _utilities.get_query_hash(query)
        )

    def lookup(self, query):
        return self._query_cache.get(self._query_key(query), self._default)

    def erase(self, query):
        query, _ = self.lookup(query)
        self._query_cache.erase(query.name)

    def complete_query(self):
        self._pending_query = False
        return self

    def start_query(self):
        if self._pending_query:
            # don't invalidate session at this point
            self.reset()
            raise issues.BadSession("Pending previous query completion!")
        self._pending_query = True
        return self

    def attach_request(self, request):
        if self._session_id is None:
            raise issues.BadSession("Empty session_id")
        request.session_id = self._session_id
        return request



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ydb._grpc.v3.protos import ydb_export_pb2 as protos_dot_ydb__export__pb2


class ExportServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExportToYt = channel.unary_unary(
                '/Ydb.Export.V1.ExportService/ExportToYt',
                request_serializer=protos_dot_ydb__export__pb2.ExportToYtRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__export__pb2.ExportToYtResponse.FromString,
                )
        self.ExportToS3 = channel.unary_unary(
                '/Ydb.Export.V1.ExportService/ExportToS3',
                request_serializer=protos_dot_ydb__export__pb2.ExportToS3Request.SerializeToString,
                response_deserializer=protos_dot_ydb__export__pb2.ExportToS3Response.FromString,
                )


class ExportServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ExportToYt(self, request, context):
        """Exports data to YT.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportToS3(self, request, context):
        """Exports data to S3.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ExportToYt': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportToYt,
                    request_deserializer=protos_dot_ydb__export__pb2.ExportToYtRequest.FromString,
                    response_serializer=protos_dot_ydb__export__pb2.ExportToYtResponse.SerializeToString,
            ),
            'ExportToS3': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportToS3,
                    request_deserializer=protos_dot_ydb__export__pb2.ExportToS3Request.FromString,
                    response_serializer=protos_dot_ydb__export__pb2.ExportToS3Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Ydb.Export.V1.ExportService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ExportService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ExportToYt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Export.V1.ExportService/ExportToYt',
            protos_dot_ydb__export__pb2.ExportToYtRequest.SerializeToString,
            protos_dot_ydb__export__pb2.ExportToYtResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExportToS3(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Export.V1.ExportService/ExportToS3',
            protos_dot_ydb__export__pb2.ExportToS3Request.SerializeToString,
            protos_dot_ydb__export__pb2.ExportToS3Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_scripting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v3.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v3.protos import ydb_table_pb2 as protos_dot_ydb__table__pb2
from ydb._grpc.v3.protos import ydb_query_stats_pb2 as protos_dot_ydb__query__stats__pb2
from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_scripting.proto',
  package='Ydb.Scripting',
  syntax='proto3',
  serialized_options=b'\n\022tech.ydb.scriptingB\017ScriptingProtosZ<github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scripting\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1aprotos/ydb_scripting.proto\x12\rYdb.Scripting\x1a\x1aprotos/ydb_operation.proto\x1a\x16protos/ydb_value.proto\x1a\x16protos/ydb_table.proto\x1a\x1cprotos/ydb_query_stats.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1dprotos/ydb_status_codes.proto\"\xa5\x02\n\x11\x45xecuteYqlRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06script\x18\x02 \x01(\t\x12\x44\n\nparameters\x18\x03 \x03(\x0b\x32\x30.Ydb.Scripting.ExecuteYqlRequest.ParametersEntry\x12;\n\rcollect_stats\x18\x04 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"B\n\x12\x45xecuteYqlResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"h\n\x10\x45xecuteYqlResult\x12#\n\x0bresult_sets\x18\x01 \x03(\x0b\x32\x0e.Ydb.ResultSet\x12/\n\x0bquery_stats\x18\x02 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"\xa7\x01\n\x19\x45xecuteYqlPartialResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x36\n\x06result\x18\x03 \x01(\x0b\x32&.Ydb.Scripting.ExecuteYqlPartialResult\"\x88\x01\n\x17\x45xecuteYqlPartialResult\x12\x18\n\x10result_set_index\x18\x01 \x01(\r\x12\"\n\nresult_set\x18\x02 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12/\n\x0bquery_stats\x18\x03 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"\xc9\x01\n\x11\x45xplainYqlRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06script\x18\x02 \x01(\t\x12\x33\n\x04mode\x18\x03 \x01(\x0e\x32%.Ydb.Scripting.ExplainYqlRequest.Mode\"4\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x0c\n\x08VALIDATE\x10\x02\x12\x08\n\x04PLAN\x10\x03\"B\n\x12\x45xplainYqlResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb3\x01\n\x10\x45xplainYqlResult\x12N\n\x10parameters_types\x18\x01 \x03(\x0b\x32\x34.Ydb.Scripting.ExplainYqlResult.ParametersTypesEntry\x12\x0c\n\x04plan\x18\x02 \x01(\t\x1a\x41\n\x14ParametersTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Ydb.Type:\x02\x38\x01\x42\x66\n\x12tech.ydb.scriptingB\x0fScriptingProtosZ<github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scripting\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,protos_dot_ydb__value__pb2.DESCRIPTOR,protos_dot_ydb__table__pb2.DESCRIPTOR,protos_dot_ydb__query__stats__pb2.DESCRIPTOR,protos_dot_ydb__issue__message__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,])



_EXPLAINYQLREQUEST_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='Ydb.Scripting.ExplainYqlRequest.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALIDATE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1143,
  serialized_end=1195,
)
_sym_db.RegisterEnumDescriptor(_EXPLAINYQLREQUEST_MODE)


_EXECUTEYQLREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='Ydb.Scripting.ExecuteYqlRequest.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Scripting.ExecuteYqlRequest.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Scripting.ExecuteYqlRequest.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=508,
)

_EXECUTEYQLREQUEST = _descriptor.Descriptor(
  name='ExecuteYqlRequest',
  full_name='Ydb.Scripting.ExecuteYqlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Scripting.ExecuteYqlRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script', full_name='Ydb.Scripting.ExecuteYqlRequest.script', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='Ydb.Scripting.ExecuteYqlRequest.parameters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collect_stats', full_name='Ydb.Scripting.ExecuteYqlRequest.collect_stats', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTEYQLREQUEST_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=508,
)


_EXECUTEYQLRESPONSE = _descriptor.Descriptor(
  name='ExecuteYqlResponse',
  full_name='Ydb.Scripting.ExecuteYqlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Scripting.ExecuteYqlResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=576,
)


_EXECUTEYQLRESULT = _descriptor.Descriptor(
  name='ExecuteYqlResult',
  full_name='Ydb.Scripting.ExecuteYqlResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_sets', full_name='Ydb.Scripting.ExecuteYqlResult.result_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_stats', full_name='Ydb.Scripting.ExecuteYqlResult.query_stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=682,
)


_EXECUTEYQLPARTIALRESPONSE = _descriptor.Descriptor(
  name='ExecuteYqlPartialResponse',
  full_name='Ydb.Scripting.ExecuteYqlPartialResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Scripting.ExecuteYqlPartialResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Scripting.ExecuteYqlPartialResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='Ydb.Scripting.ExecuteYqlPartialResponse.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=852,
)


_EXECUTEYQLPARTIALRESULT = _descriptor.Descriptor(
  name='ExecuteYqlPartialResult',
  full_name='Ydb.Scripting.ExecuteYqlPartialResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_set_index', full_name='Ydb.Scripting.ExecuteYqlPartialResult.result_set_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set', full_name='Ydb.Scripting.ExecuteYqlPartialResult.result_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_stats', full_name='Ydb.Scripting.ExecuteYqlPartialResult.query_stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=991,
)


_EXPLAINYQLREQUEST = _descriptor.Descriptor(
  name='ExplainYqlRequest',
  full_name='Ydb.Scripting.ExplainYqlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Scripting.ExplainYqlRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script', full_name='Ydb.Scripting.ExplainYqlRequest.script', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='Ydb.Scripting.ExplainYqlRequest.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXPLAINYQLREQUEST_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1195,
)


_EXPLAINYQLRESPONSE = _descriptor.Descriptor(
  name='ExplainYqlResponse',
  full_name='Ydb.Scripting.ExplainYqlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Scripting.ExplainYqlResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1197,
  serialized_end=1263,
)


_EXPLAINYQLRESULT_PARAMETERSTYPESENTRY = _descriptor.Descriptor(
  name='ParametersTypesEntry',
  full_name='Ydb.Scripting.ExplainYqlResult.ParametersTypesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Scripting.ExplainYqlResult.ParametersTypesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Scripting.ExplainYqlResult.ParametersTypesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1380,
  serialized_end=1445,
)

_EXPLAINYQLRESULT = _descriptor.Descriptor(
  name='ExplainYqlResult',
  full_name='Ydb.Scripting.ExplainYqlResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters_types', full_name='Ydb.Scripting.ExplainYqlResult.parameters_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan', full_name='Ydb.Scripting.ExplainYqlResult.plan', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXPLAINYQLRESULT_PARAMETERSTYPESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1445,
)

_EXECUTEYQLREQUEST_PARAMETERSENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_EXECUTEYQLREQUEST_PARAMETERSENTRY.containing_type = _EXECUTEYQLREQUEST
_EXECUTEYQLREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXECUTEYQLREQUEST.fields_by_name['parameters'].message_type = _EXECUTEYQLREQUEST_PARAMETERSENTRY
_EXECUTEYQLREQUEST.fields_by_name['collect_stats'].enum_type = protos_dot_ydb__table__pb2._QUERYSTATSCOLLECTION_MODE
_EXECUTEYQLRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_EXECUTEYQLRESULT.fields_by_name['result_sets'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_EXECUTEYQLRESULT.fields_by_name['query_stats'].message_type = protos_dot_ydb__query__stats__pb2._QUERYSTATS
_EXECUTEYQLPARTIALRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_EXECUTEYQLPARTIALRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_EXECUTEYQLPARTIALRESPONSE.fields_by_name['result'].message_type = _EXECUTEYQLPARTIALRESULT
_EXECUTEYQLPARTIALRESULT.fields_by_name['result_set'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_EXECUTEYQLPARTIALRESULT.fields_by_name['query_stats'].message_type = protos_dot_ydb__query__stats__pb2._QUERYSTATS
_EXPLAINYQLREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXPLAINYQLREQUEST.fields_by_name['mode'].enum_type = _EXPLAINYQLREQUEST_MODE
_EXPLAINYQLREQUEST_MODE.containing_type = _EXPLAINYQLREQUEST
_EXPLAINYQLRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_EXPLAINYQLRESULT_PARAMETERSTYPESENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPE
_EXPLAINYQLRESULT_PARAMETERSTYPESENTRY.containing_type = _EXPLAINYQLRESULT
_EXPLAINYQLRESULT.fields_by_name['parameters_types'].message_type = _EXPLAINYQLRESULT_PARAMETERSTYPESENTRY
DESCRIPTOR.message_types_by_name['ExecuteYqlRequest'] = _EXECUTEYQLREQUEST
DESCRIPTOR.message_types_by_name['ExecuteYqlResponse'] = _EXECUTEYQLRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteYqlResult'] = _EXECUTEYQLRESULT
DESCRIPTOR.message_types_by_name['ExecuteYqlPartialResponse'] = _EXECUTEYQLPARTIALRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteYqlPartialResult'] = _EXECUTEYQLPARTIALRESULT
DESCRIPTOR.message_types_by_name['ExplainYqlRequest'] = _EXPLAINYQLREQUEST
DESCRIPTOR.message_types_by_name['ExplainYqlResponse'] = _EXPLAINYQLRESPONSE
DESCRIPTOR.message_types_by_name['ExplainYqlResult'] = _EXPLAINYQLRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExecuteYqlRequest = _reflection.GeneratedProtocolMessageType('ExecuteYqlRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEYQLREQUEST_PARAMETERSENTRY,
    '__module__' : 'protos.ydb_scripting_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExecuteYqlRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTEYQLREQUEST,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExecuteYqlRequest)
  })
_sym_db.RegisterMessage(ExecuteYqlRequest)
_sym_db.RegisterMessage(ExecuteYqlRequest.ParametersEntry)

ExecuteYqlResponse = _reflection.GeneratedProtocolMessageType('ExecuteYqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEYQLRESPONSE,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExecuteYqlResponse)
  })
_sym_db.RegisterMessage(ExecuteYqlResponse)

ExecuteYqlResult = _reflection.GeneratedProtocolMessageType('ExecuteYqlResult', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEYQLRESULT,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExecuteYqlResult)
  })
_sym_db.RegisterMessage(ExecuteYqlResult)

ExecuteYqlPartialResponse = _reflection.GeneratedProtocolMessageType('ExecuteYqlPartialResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEYQLPARTIALRESPONSE,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExecuteYqlPartialResponse)
  })
_sym_db.RegisterMessage(ExecuteYqlPartialResponse)

ExecuteYqlPartialResult = _reflection.GeneratedProtocolMessageType('ExecuteYqlPartialResult', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEYQLPARTIALRESULT,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExecuteYqlPartialResult)
  })
_sym_db.RegisterMessage(ExecuteYqlPartialResult)

ExplainYqlRequest = _reflection.GeneratedProtocolMessageType('ExplainYqlRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPLAINYQLREQUEST,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExplainYqlRequest)
  })
_sym_db.RegisterMessage(ExplainYqlRequest)

ExplainYqlResponse = _reflection.GeneratedProtocolMessageType('ExplainYqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXPLAINYQLRESPONSE,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExplainYqlResponse)
  })
_sym_db.RegisterMessage(ExplainYqlResponse)

ExplainYqlResult = _reflection.GeneratedProtocolMessageType('ExplainYqlResult', (_message.Message,), {

  'ParametersTypesEntry' : _reflection.GeneratedProtocolMessageType('ParametersTypesEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXPLAINYQLRESULT_PARAMETERSTYPESENTRY,
    '__module__' : 'protos.ydb_scripting_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExplainYqlResult.ParametersTypesEntry)
    })
  ,
  'DESCRIPTOR' : _EXPLAINYQLRESULT,
  '__module__' : 'protos.ydb_scripting_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Scripting.ExplainYqlResult)
  })
_sym_db.RegisterMessage(ExplainYqlResult)
_sym_db.RegisterMessage(ExplainYqlResult.ParametersTypesEntry)


DESCRIPTOR._options = None
_EXECUTEYQLREQUEST_PARAMETERSENTRY._options = None
_EXPLAINYQLRESULT_PARAMETERSTYPESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_export.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v4.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17protos/ydb_export.proto\x12\nYdb.Export\x1a#protos/annotations/validation.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb1\x01\n\x0e\x45xportProgress\"\x9e\x01\n\x08Progress\x12\x18\n\x14PROGRESS_UNSPECIFIED\x10\x00\x12\x16\n\x12PROGRESS_PREPARING\x10\x01\x12\x1a\n\x16PROGRESS_TRANSFER_DATA\x10\x02\x12\x11\n\rPROGRESS_DONE\x10\x03\x12\x19\n\x15PROGRESS_CANCELLATION\x10\x04\x12\x16\n\x12PROGRESS_CANCELLED\x10\x05\"\xa0\x01\n\x12\x45xportItemProgress\x12\x13\n\x0bparts_total\x18\x01 \x01(\r\x12\x17\n\x0fparts_completed\x18\x02 \x01(\r\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x98\x02\n\x12\x45xportToYtSettings\x12\x12\n\x04host\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x13\n\x05token\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12:\n\x05items\x18\x04 \x03(\x0b\x32#.Ydb.Export.ExportToYtSettings.ItemB\x06\x9a\xe6*\x02(\x01\x12\x1c\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x06 \x01(\r\x12\x13\n\x0buse_type_v3\x18\x07 \x01(\x08\x1a\x41\n\x04Item\x12\x19\n\x0bsource_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x1e\n\x10\x64\x65stination_path\x18\x02 \x01(\tB\x04\x90\xe6*\x01\"\x12\n\x10\x45xportToYtResult\"\xb5\x01\n\x12\x45xportToYtMetadata\x12\x30\n\x08settings\x18\x01 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Export.ExportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Export.ExportItemProgress\"\x86\x01\n\x11\x45xportToYtRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettingsB\x04\x90\xe6*\x01\"B\n\x12\x45xportToYtResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xbd\x05\n\x12\x45xportToS3Settings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x35\n\x06scheme\x18\x02 \x01(\x0e\x32%.Ydb.Export.ExportToS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12:\n\x05items\x18\x06 \x03(\x0b\x32#.Ydb.Export.ExportToS3Settings.ItemB\x06\x9a\xe6*\x02(\x01\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x08 \x01(\r\x12\x42\n\rstorage_class\x18\t \x01(\x0e\x32+.Ydb.Export.ExportToS3Settings.StorageClass\x12\x13\n\x0b\x63ompression\x18\n \x01(\t\x12\x0e\n\x06region\x18\x0b \x01(\t\x1a\x43\n\x04Item\x12\x19\n\x0bsource_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12 \n\x12\x64\x65stination_prefix\x18\x02 \x01(\tB\x04\x90\xe6*\x01\".\n\x06Scheme\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\"\xba\x01\n\x0cStorageClass\x12\x1d\n\x19STORAGE_CLASS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x16\n\x12REDUCED_REDUNDANCY\x10\x02\x12\x0f\n\x0bSTANDARD_IA\x10\x03\x12\x0e\n\nONEZONE_IA\x10\x04\x12\x17\n\x13INTELLIGENT_TIERING\x10\x05\x12\x0b\n\x07GLACIER\x10\x06\x12\x10\n\x0c\x44\x45\x45P_ARCHIVE\x10\x07\x12\x0c\n\x08OUTPOSTS\x10\x08\"\x12\n\x10\x45xportToS3Result\"\xb5\x01\n\x12\x45xportToS3Metadata\x12\x30\n\x08settings\x18\x01 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3Settings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Export.ExportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Export.ExportItemProgress\"\x86\x01\n\x11\x45xportToS3Request\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3SettingsB\x04\x90\xe6*\x01\"B\n\x12\x45xportToS3Response\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBO\n\x0ftech.ydb.exportZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Export\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_export_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017tech.ydb.exportZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Export\370\001\001'
  _EXPORTTOYTSETTINGS_ITEM.fields_by_name['source_path']._options = None
  _EXPORTTOYTSETTINGS_ITEM.fields_by_name['source_path']._serialized_options = b'\220\346*\001'
  _EXPORTTOYTSETTINGS_ITEM.fields_by_name['destination_path']._options = None
  _EXPORTTOYTSETTINGS_ITEM.fields_by_name['destination_path']._serialized_options = b'\220\346*\001'
  _EXPORTTOYTSETTINGS.fields_by_name['host']._options = None
  _EXPORTTOYTSETTINGS.fields_by_name['host']._serialized_options = b'\220\346*\001'
  _EXPORTTOYTSETTINGS.fields_by_name['token']._options = None
  _EXPORTTOYTSETTINGS.fields_by_name['token']._serialized_options = b'\220\346*\001'
  _EXPORTTOYTSETTINGS.fields_by_name['items']._options = None
  _EXPORTTOYTSETTINGS.fields_by_name['items']._serialized_options = b'\232\346*\002(\001'
  _EXPORTTOYTSETTINGS.fields_by_name['description']._options = None
  _EXPORTTOYTSETTINGS.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200\001'
  _EXPORTTOYTREQUEST.fields_by_name['settings']._options = None
  _EXPORTTOYTREQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _EXPORTTOS3SETTINGS_ITEM.fields_by_name['source_path']._options = None
  _EXPORTTOS3SETTINGS_ITEM.fields_by_name['source_path']._serialized_options = b'\220\346*\001'
  _EXPORTTOS3SETTINGS_ITEM.fields_by_name['destination_prefix']._options = None
  _EXPORTTOS3SETTINGS_ITEM.fields_by_name['destination_prefix']._serialized_options = b'\220\346*\001'
  _EXPORTTOS3SETTINGS.fields_by_name['endpoint']._options = None
  _EXPORTTOS3SETTINGS.fields_by_name['endpoint']._serialized_options = b'\220\346*\001'
  _EXPORTTOS3SETTINGS.fields_by_name['bucket']._options = None
  _EXPORTTOS3SETTINGS.fields_by_name['bucket']._serialized_options = b'\220\346*\001'
  _EXPORTTOS3SETTINGS.fields_by_name['access_key']._options = None
  _EXPORTTOS3SETTINGS.fields_by_name['access_key']._serialized_options = b'\220\346*\001'
  _EXPORTTOS3SETTINGS.fields_by_name['secret_key']._options = None
  _EXPORTTOS3SETTINGS.fields_by_name['secret_key']._serialized_options = b'\220\346*\001'
  _EXPORTTOS3SETTINGS.fields_by_name['items']._options = None
  _EXPORTTOS3SETTINGS.fields_by_name['items']._serialized_options = b'\232\346*\002(\001'
  _EXPORTTOS3SETTINGS.fields_by_name['description']._options = None
  _EXPORTTOS3SETTINGS.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200\001'
  _EXPORTTOS3REQUEST.fields_by_name['settings']._options = None
  _EXPORTTOS3REQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _EXPORTPROGRESS._serialized_start=138
  _EXPORTPROGRESS._serialized_end=315
  _EXPORTPROGRESS_PROGRESS._serialized_start=157
  _EXPORTPROGRESS_PROGRESS._serialized_end=315
  _EXPORTITEMPROGRESS._serialized_start=318
  _EXPORTITEMPROGRESS._serialized_end=478
  _EXPORTTOYTSETTINGS._serialized_start=481
  _EXPORTTOYTSETTINGS._serialized_end=761
  _EXPORTTOYTSETTINGS_ITEM._serialized_start=696
  _EXPORTTOYTSETTINGS_ITEM._serialized_end=761
  _EXPORTTOYTRESULT._serialized_start=763
  _EXPORTTOYTRESULT._serialized_end=781
  _EXPORTTOYTMETADATA._serialized_start=784
  _EXPORTTOYTMETADATA._serialized_end=965
  _EXPORTTOYTREQUEST._serialized_start=968
  _EXPORTTOYTREQUEST._serialized_end=1102
  _EXPORTTOYTRESPONSE._serialized_start=1104
  _EXPORTTOYTRESPONSE._serialized_end=1170
  _EXPORTTOS3SETTINGS._serialized_start=1173
  _EXPORTTOS3SETTINGS._serialized_end=1874
  _EXPORTTOS3SETTINGS_ITEM._serialized_start=1570
  _EXPORTTOS3SETTINGS_ITEM._serialized_end=1637
  _EXPORTTOS3SETTINGS_SCHEME._serialized_start=1639
  _EXPORTTOS3SETTINGS_SCHEME._serialized_end=1685
  _EXPORTTOS3SETTINGS_STORAGECLASS._serialized_start=1688
  _EXPORTTOS3SETTINGS_STORAGECLASS._serialized_end=1874
  _EXPORTTOS3RESULT._serialized_start=1876
  _EXPORTTOS3RESULT._serialized_end=1894
  _EXPORTTOS3METADATA._serialized_start=1897
  _EXPORTTOS3METADATA._serialized_end=2078
  _EXPORTTOS3REQUEST._serialized_start=2081
  _EXPORTTOS3REQUEST._serialized_end=2215
  _EXPORTTOS3RESPONSE._serialized_start=2217
  _EXPORTTOS3RESPONSE._serialized_end=2283
# @@protoc_insertion_point(module_scope)



from .credentials import *  # noqa
from .driver import *  # noqa
from .table import *  # noqa
from .issues import *  # noqa
from .types import *  # noqa
from .scheme import *  # noqa
from .settings import *  # noqa
from .resolver import *  # noqa
from .export import *  # noqa
from .auth_helpers import *  # noqa
from .operation import *  # noqa
from .scripting import *  # noqa
from .import_client import *  # noqa
from .tracing import *  # noqa

try:
    import ydb.aio as aio  # noqa
except Exception:
    pass



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_status_codes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprotos/ydb_status_codes.proto\x12\x03Ydb\"\xa7\x03\n\tStatusIds\"\x99\x03\n\nStatusCode\x12\x1b\n\x17STATUS_CODE_UNSPECIFIED\x10\x00\x12\r\n\x07SUCCESS\x10\x80\xb5\x18\x12\x11\n\x0b\x42\x41\x44_REQUEST\x10\x8a\xb5\x18\x12\x12\n\x0cUNAUTHORIZED\x10\x94\xb5\x18\x12\x14\n\x0eINTERNAL_ERROR\x10\x9e\xb5\x18\x12\r\n\x07\x41\x42ORTED\x10\xa8\xb5\x18\x12\x11\n\x0bUNAVAILABLE\x10\xb2\xb5\x18\x12\x10\n\nOVERLOADED\x10\xbc\xb5\x18\x12\x12\n\x0cSCHEME_ERROR\x10\xc6\xb5\x18\x12\x13\n\rGENERIC_ERROR\x10\xd0\xb5\x18\x12\r\n\x07TIMEOUT\x10\xda\xb5\x18\x12\x11\n\x0b\x42\x41\x44_SESSION\x10\xe4\xb5\x18\x12\x19\n\x13PRECONDITION_FAILED\x10\xf8\xb5\x18\x12\x14\n\x0e\x41LREADY_EXISTS\x10\x82\xb6\x18\x12\x0f\n\tNOT_FOUND\x10\x8c\xb6\x18\x12\x15\n\x0fSESSION_EXPIRED\x10\x96\xb6\x18\x12\x0f\n\tCANCELLED\x10\xa0\xb6\x18\x12\x12\n\x0cUNDETERMINED\x10\xaa\xb6\x18\x12\x11\n\x0bUNSUPPORTED\x10\xb4\xb6\x18\x12\x12\n\x0cSESSION_BUSY\x10\xbe\xb6\x18\x42Q\n\x08tech.ydbB\x11StatusCodesProtosZ2github.com/ydb-platform/ydb-go-genproto/protos/Ydbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_status_codes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\010tech.ydbB\021StatusCodesProtosZ2github.com/ydb-platform/ydb-go-genproto/protos/Ydb'
  _STATUSIDS._serialized_start=39
  _STATUSIDS._serialized_end=462
  _STATUSIDS_STATUSCODE._serialized_start=53
  _STATUSIDS_STATUSCODE._serialized_end=462
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import Optional

from ydb import issues

_errors_retriable_fast_backoff_types = [
    issues.Unavailable,
]
_errors_retriable_slow_backoff_types = [
    issues.Aborted,
    issues.BadSession,
    issues.Overloaded,
    issues.SessionPoolEmpty,
    issues.ConnectionError,
]
_errors_retriable_slow_backoff_idempotent_types = [
    issues.Undetermined,
]


def check_retriable_error(err, retry_settings, attempt):
    if isinstance(err, issues.NotFound):
        if retry_settings.retry_not_found:
            return ErrorRetryInfo(
                True, retry_settings.fast_backoff.calc_timeout(attempt)
            )
        else:
            return ErrorRetryInfo(False, None)

    if isinstance(err, issues.InternalError):
        if retry_settings.retry_internal_error:
            return ErrorRetryInfo(
                True, retry_settings.slow_backoff.calc_timeout(attempt)
            )
        else:
            return ErrorRetryInfo(False, None)

    for t in _errors_retriable_fast_backoff_types:
        if isinstance(err, t):
            return ErrorRetryInfo(
                True, retry_settings.fast_backoff.calc_timeout(attempt)
            )

    for t in _errors_retriable_slow_backoff_types:
        if isinstance(err, t):
            return ErrorRetryInfo(
                True, retry_settings.slow_backoff.calc_timeout(attempt)
            )

    if retry_settings.idempotent:
        for t in _errors_retriable_slow_backoff_idempotent_types:
            return ErrorRetryInfo(
                True, retry_settings.slow_backoff.calc_timeout(attempt)
            )

    return ErrorRetryInfo(False, None)


@dataclass
class ErrorRetryInfo:
    is_retriable: bool
    sleep_timeout_seconds: Optional[float]



import time

import abc
import asyncio
import logging
import six
from ydb import issues, credentials

logger = logging.getLogger(__name__)


class _OneToManyValue(object):
    def __init__(self):
        self._value = None
        self._condition = asyncio.Condition()

    async def consume(self, timeout=3):
        async with self._condition:
            if self._value is None:
                try:
                    await asyncio.wait_for(self._condition.wait(), timeout=timeout)
                except Exception:
                    return self._value
            return self._value

    async def update(self, n_value):
        async with self._condition:
            prev_value = self._value
            self._value = n_value
            if prev_value is None:
                self._condition.notify_all()


class _AtMostOneExecution(object):
    def __init__(self):
        self._can_schedule = True
        self._lock = asyncio.Lock()  # Lock to guarantee only one execution

    async def _wrapped_execution(self, callback):
        await self._lock.acquire()
        try:
            res = callback()
            if asyncio.iscoroutine(res):
                await res
        except Exception:
            pass

        finally:
            self._lock.release()
            self._can_schedule = True

    def submit(self, callback):
        if self._can_schedule:
            self._can_schedule = False
            asyncio.ensure_future(self._wrapped_execution(callback))


@six.add_metaclass(abc.ABCMeta)
class AbstractExpiringTokenCredentials(credentials.AbstractExpiringTokenCredentials):
    def __init__(self):
        super(AbstractExpiringTokenCredentials, self).__init__()
        self._tp = _AtMostOneExecution()
        self._cached_token = _OneToManyValue()

    @abc.abstractmethod
    async def _make_token_request(self):
        pass

    async def _refresh(self):
        current_time = time.time()
        self._log_refresh_start(current_time)

        try:
            auth_metadata = await self._make_token_request()
            await self._cached_token.update(auth_metadata["access_token"])
            self.update_expiration_info(auth_metadata)
            self.logger.info(
                "Token refresh successful. current_time %s, refresh_in %s",
                current_time,
                self._refresh_in,
            )

        except (KeyboardInterrupt, SystemExit):
            return

        except Exception as e:
            self.last_error = str(e)
            await asyncio.sleep(1)
            self._tp.submit(self._refresh)

    async def token(self):
        current_time = time.time()
        if current_time > self._refresh_in:
            self._tp.submit(self._refresh)

        cached_token = await self._cached_token.consume(timeout=3)
        if cached_token is None:
            if self.last_error is None:
                raise issues.ConnectionError(
                    "%s: timeout occurred while waiting for token.\n%s"
                    % (
                        self.__class__.__name__,
                        self.extra_error_message,
                    )
                )
            raise issues.ConnectionError(
                "%s: %s.\n%s"
                % (self.__class__.__name__, self.last_error, self.extra_error_message)
            )
        return cached_token

    async def auth_metadata(self):
        return [(credentials.YDB_AUTH_TICKET_HEADER, await self.token())]



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_discovery.proto',
  package='Ydb.Discovery',
  syntax='proto3',
  serialized_options=b'\n\022tech.ydb.discoveryB\017DiscoveryProtosZ<github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Discovery\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1aprotos/ydb_discovery.proto\x12\rYdb.Discovery\x1a\x1aprotos/ydb_operation.proto\"9\n\x14ListEndpointsRequest\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x03(\t\"\xc3\x01\n\x0c\x45ndpointInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x13\n\x0bload_factor\x18\x03 \x01(\x02\x12\x0b\n\x03ssl\x18\x04 \x01(\x08\x12\x0f\n\x07service\x18\x05 \x03(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0f\n\x07node_id\x18\x07 \x01(\r\x12\r\n\x05ip_v4\x18\x08 \x03(\t\x12\r\n\x05ip_v6\x18\t \x03(\t\x12 \n\x18ssl_target_name_override\x18\n \x01(\t\"\\\n\x13ListEndpointsResult\x12.\n\tendpoints\x18\x01 \x03(\x0b\x32\x1b.Ydb.Discovery.EndpointInfo\x12\x15\n\rself_location\x18\x02 \x01(\t\"E\n\x15ListEndpointsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\'\n\rWhoAmIRequest\x12\x16\n\x0einclude_groups\x18\x01 \x01(\x08\",\n\x0cWhoAmIResult\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06groups\x18\x02 \x03(\t\">\n\x0eWhoAmIResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBf\n\x12tech.ydb.discoveryB\x0f\x44iscoveryProtosZ<github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Discovery\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])




_LISTENDPOINTSREQUEST = _descriptor.Descriptor(
  name='ListEndpointsRequest',
  full_name='Ydb.Discovery.ListEndpointsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='Ydb.Discovery.ListEndpointsRequest.database', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='Ydb.Discovery.ListEndpointsRequest.service', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=130,
)


_ENDPOINTINFO = _descriptor.Descriptor(
  name='EndpointInfo',
  full_name='Ydb.Discovery.EndpointInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='Ydb.Discovery.EndpointInfo.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Ydb.Discovery.EndpointInfo.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_factor', full_name='Ydb.Discovery.EndpointInfo.load_factor', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl', full_name='Ydb.Discovery.EndpointInfo.ssl', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='Ydb.Discovery.EndpointInfo.service', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='Ydb.Discovery.EndpointInfo.location', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.Discovery.EndpointInfo.node_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_v4', full_name='Ydb.Discovery.EndpointInfo.ip_v4', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_v6', full_name='Ydb.Discovery.EndpointInfo.ip_v6', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_target_name_override', full_name='Ydb.Discovery.EndpointInfo.ssl_target_name_override', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=328,
)


_LISTENDPOINTSRESULT = _descriptor.Descriptor(
  name='ListEndpointsResult',
  full_name='Ydb.Discovery.ListEndpointsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='Ydb.Discovery.ListEndpointsResult.endpoints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self_location', full_name='Ydb.Discovery.ListEndpointsResult.self_location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=422,
)


_LISTENDPOINTSRESPONSE = _descriptor.Descriptor(
  name='ListEndpointsResponse',
  full_name='Ydb.Discovery.ListEndpointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Discovery.ListEndpointsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=493,
)


_WHOAMIREQUEST = _descriptor.Descriptor(
  name='WhoAmIRequest',
  full_name='Ydb.Discovery.WhoAmIRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_groups', full_name='Ydb.Discovery.WhoAmIRequest.include_groups', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=495,
  serialized_end=534,
)


_WHOAMIRESULT = _descriptor.Descriptor(
  name='WhoAmIResult',
  full_name='Ydb.Discovery.WhoAmIResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='Ydb.Discovery.WhoAmIResult.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='Ydb.Discovery.WhoAmIResult.groups', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=580,
)


_WHOAMIRESPONSE = _descriptor.Descriptor(
  name='WhoAmIResponse',
  full_name='Ydb.Discovery.WhoAmIResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Discovery.WhoAmIResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=644,
)

_LISTENDPOINTSRESULT.fields_by_name['endpoints'].message_type = _ENDPOINTINFO
_LISTENDPOINTSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_WHOAMIRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['ListEndpointsRequest'] = _LISTENDPOINTSREQUEST
DESCRIPTOR.message_types_by_name['EndpointInfo'] = _ENDPOINTINFO
DESCRIPTOR.message_types_by_name['ListEndpointsResult'] = _LISTENDPOINTSRESULT
DESCRIPTOR.message_types_by_name['ListEndpointsResponse'] = _LISTENDPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['WhoAmIRequest'] = _WHOAMIREQUEST
DESCRIPTOR.message_types_by_name['WhoAmIResult'] = _WHOAMIRESULT
DESCRIPTOR.message_types_by_name['WhoAmIResponse'] = _WHOAMIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListEndpointsRequest = _reflection.GeneratedProtocolMessageType('ListEndpointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENDPOINTSREQUEST,
  '__module__' : 'protos.ydb_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Discovery.ListEndpointsRequest)
  })
_sym_db.RegisterMessage(ListEndpointsRequest)

EndpointInfo = _reflection.GeneratedProtocolMessageType('EndpointInfo', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTINFO,
  '__module__' : 'protos.ydb_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Discovery.EndpointInfo)
  })
_sym_db.RegisterMessage(EndpointInfo)

ListEndpointsResult = _reflection.GeneratedProtocolMessageType('ListEndpointsResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTENDPOINTSRESULT,
  '__module__' : 'protos.ydb_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Discovery.ListEndpointsResult)
  })
_sym_db.RegisterMessage(ListEndpointsResult)

ListEndpointsResponse = _reflection.GeneratedProtocolMessageType('ListEndpointsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENDPOINTSRESPONSE,
  '__module__' : 'protos.ydb_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Discovery.ListEndpointsResponse)
  })
_sym_db.RegisterMessage(ListEndpointsResponse)

WhoAmIRequest = _reflection.GeneratedProtocolMessageType('WhoAmIRequest', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIREQUEST,
  '__module__' : 'protos.ydb_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Discovery.WhoAmIRequest)
  })
_sym_db.RegisterMessage(WhoAmIRequest)

WhoAmIResult = _reflection.GeneratedProtocolMessageType('WhoAmIResult', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIRESULT,
  '__module__' : 'protos.ydb_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Discovery.WhoAmIResult)
  })
_sym_db.RegisterMessage(WhoAmIResult)

WhoAmIResponse = _reflection.GeneratedProtocolMessageType('WhoAmIResponse', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIRESPONSE,
  '__module__' : 'protos.ydb_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Discovery.WhoAmIResponse)
  })
_sym_db.RegisterMessage(WhoAmIResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_scheme.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos import ydb_common_pb2 as protos_dot_ydb__common__pb2
from ydb._grpc.v4.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17protos/ydb_scheme.proto\x12\nYdb.Scheme\x1a\x17protos/ydb_common.proto\x1a\x1aprotos/ydb_operation.proto\"_\n\x14MakeDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"E\n\x15MakeDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"a\n\x16RemoveDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"G\n\x17RemoveDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x14ListDirectoryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"E\n\x15ListDirectoryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"8\n\x0bPermissions\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x18\n\x10permission_names\x18\x02 \x03(\t\"\xda\x03\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12$\n\x04type\x18\x05 \x01(\x0e\x32\x16.Ydb.Scheme.Entry.Type\x12\x36\n\x15\x65\x66\x66\x65\x63tive_permissions\x18\x06 \x03(\x0b\x32\x17.Ydb.Scheme.Permissions\x12,\n\x0bpermissions\x18\x07 \x03(\x0b\x32\x17.Ydb.Scheme.Permissions\x12\x12\n\nsize_bytes\x18\x08 \x01(\x04\x12)\n\ncreated_at\x18\t \x01(\x0b\x32\x15.Ydb.VirtualTimestamp\"\xe8\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDIRECTORY\x10\x01\x12\t\n\x05TABLE\x10\x02\x12\x14\n\x10PERS_QUEUE_GROUP\x10\x03\x12\x0c\n\x08\x44\x41TABASE\x10\x04\x12\x0f\n\x0bRTMR_VOLUME\x10\x05\x12\x16\n\x12\x42LOCK_STORE_VOLUME\x10\x06\x12\x15\n\x11\x43OORDINATION_NODE\x10\x07\x12\x10\n\x0c\x43OLUMN_STORE\x10\x0c\x12\x10\n\x0c\x43OLUMN_TABLE\x10\r\x12\x0c\n\x08SEQUENCE\x10\x0f\x12\x0f\n\x0bREPLICATION\x10\x10\x12\t\n\x05TOPIC\x10\x11\"[\n\x13ListDirectoryResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12#\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x11.Ydb.Scheme.Entry\"^\n\x13\x44\x65scribePathRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"D\n\x14\x44\x65scribePathResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"5\n\x12\x44\x65scribePathResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\"\xb2\x01\n\x11PermissionsAction\x12(\n\x05grant\x18\x01 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12)\n\x06revoke\x18\x02 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12&\n\x03set\x18\x03 \x01(\x0b\x32\x17.Ydb.Scheme.PermissionsH\x00\x12\x16\n\x0c\x63hange_owner\x18\x04 \x01(\tH\x00\x42\x08\n\x06\x61\x63tion\"\xde\x01\n\x18ModifyPermissionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12.\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x1d.Ydb.Scheme.PermissionsAction\x12\x19\n\x11\x63lear_permissions\x18\x04 \x01(\x08\x12\x1f\n\x15interrupt_inheritance\x18\x05 \x01(\x08H\x00\x42\r\n\x0binheritance\"I\n\x19ModifyPermissionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBf\n\x0ftech.ydb.schemeB\x15SchemeOperationProtosZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scheme\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_scheme_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017tech.ydb.schemeB\025SchemeOperationProtosZ9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Scheme\370\001\001'
  _MAKEDIRECTORYREQUEST._serialized_start=92
  _MAKEDIRECTORYREQUEST._serialized_end=187
  _MAKEDIRECTORYRESPONSE._serialized_start=189
  _MAKEDIRECTORYRESPONSE._serialized_end=258
  _REMOVEDIRECTORYREQUEST._serialized_start=260
  _REMOVEDIRECTORYREQUEST._serialized_end=357
  _REMOVEDIRECTORYRESPONSE._serialized_start=359
  _REMOVEDIRECTORYRESPONSE._serialized_end=430
  _LISTDIRECTORYREQUEST._serialized_start=432
  _LISTDIRECTORYREQUEST._serialized_end=527
  _LISTDIRECTORYRESPONSE._serialized_start=529
  _LISTDIRECTORYRESPONSE._serialized_end=598
  _PERMISSIONS._serialized_start=600
  _PERMISSIONS._serialized_end=656
  _ENTRY._serialized_start=659
  _ENTRY._serialized_end=1133
  _ENTRY_TYPE._serialized_start=901
  _ENTRY_TYPE._serialized_end=1133
  _LISTDIRECTORYRESULT._serialized_start=1135
  _LISTDIRECTORYRESULT._serialized_end=1226
  _DESCRIBEPATHREQUEST._serialized_start=1228
  _DESCRIBEPATHREQUEST._serialized_end=1322
  _DESCRIBEPATHRESPONSE._serialized_start=1324
  _DESCRIBEPATHRESPONSE._serialized_end=1392
  _DESCRIBEPATHRESULT._serialized_start=1394
  _DESCRIBEPATHRESULT._serialized_end=1447
  _PERMISSIONSACTION._serialized_start=1450
  _PERMISSIONSACTION._serialized_end=1628
  _MODIFYPERMISSIONSREQUEST._serialized_start=1631
  _MODIFYPERMISSIONSREQUEST._serialized_end=1853
  _MODIFYPERMISSIONSRESPONSE._serialized_start=1855
  _MODIFYPERMISSIONSRESPONSE._serialized_end=1928
# @@protoc_insertion_point(module_scope)
